summaryrefslogtreecommitdiffstats
path: root/kdat/TapeManager.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:25:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:25:18 +0000
commitaa3a1ca934bc541bddd3fa136a85f106f7da266e (patch)
tree9ad0b795aed8fa4ac30c2fe0fd1aacb8175714c0 /kdat/TapeManager.h
parentb10cf7066791a2f362495890cd50c984e8025412 (diff)
downloadtdeadmin-aa3a1ca934bc541bddd3fa136a85f106f7da266e.tar.gz
tdeadmin-aa3a1ca934bc541bddd3fa136a85f106f7da266e.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeadmin@1157635 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdat/TapeManager.h')
-rw-r--r--kdat/TapeManager.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kdat/TapeManager.h b/kdat/TapeManager.h
index bc91aab..b571605 100644
--- a/kdat/TapeManager.h
+++ b/kdat/TapeManager.h
@@ -19,9 +19,9 @@
#ifndef _TapeManager_h_
#define _TapeManager_h_
-#include <qdict.h>
-#include <qobject.h>
-#include <qstrlist.h>
+#include <tqdict.h>
+#include <tqobject.h>
+#include <tqstrlist.h>
#include "Tape.h"
@@ -41,13 +41,13 @@
*
* The TapeManager follows the Singleton pattern.
*/
-class TapeManager : public QObject {
+class TapeManager : public TQObject {
Q_OBJECT
static TapeManager* _instance;
- QDict<Tape> _tapes;
- QStringList _tapeIDs;
+ TQDict<Tape> _tapes;
+ TQStringList _tapeIDs;
Tape* _mountedTape;
TapeManager();
@@ -64,9 +64,9 @@ public:
/**
* Get the list of all known tape IDs.
*
* @return a QStringList containing the tape IDs.
*/
- const QStringList& getTapeIDs();
+ const TQStringList& getTapeIDs();
/**
* Retrieve the index for a tape.
@@ -74,7 +74,7 @@ public:
* @param id the ID of the tape.
* @return the tape's index.
*/
- Tape* findTape( const QString & id );
+ Tape* findTape( const TQString & id );
/**
* Add a new tape index.
@@ -64,9 +64,9 @@ public:
* Get the list of all known tape IDs.
*
- * @return a QStringList containing the tape IDs.
+ * @return a TQStringList containing the tape IDs.
*/